aboutgitcodebugslistschat
path: root/passt.h
diff options
context:
space:
mode:
Diffstat (limited to 'passt.h')
-rw-r--r--passt.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/passt.h b/passt.h
index 73fe808..d314596 100644
--- a/passt.h
+++ b/passt.h
@@ -181,7 +181,8 @@ struct ip6_ctx {
* @ip6: IPv6 configuration
* @pasta_ifn: Name of namespace interface for pasta
* @pasta_ifn: Index of namespace interface for pasta
* @pasta_conf_ns: Configure namespace interface after creating it
* @no_tcp: Disable TCP operation
* @tcp: Context for TCP protocol handler
* @no_tcp: Disable UDP operation
@@ -240,6 +241,7 @@ struct ctx {
char pasta_ifn[IF_NAMESIZE];
unsigned int pasta_ifi;
int pasta_conf_ns;
+ int no_copy_routes;
int no_tcp;
struct tcp_ctx tcp;
@@ -181,7 +181,8 @@ struct ip6_ctx {
* @pasta_ifn: Name of namespace interface for pasta
* @pasta_ifn: Index of namespace interface for pasta
- * @pasta_conf_ns: Configure namespace interface after creating it
+ * @pasta_conf_ns: Configure namespace after creating it
+ * @no_copy_routes: Don't copy all routes when configuring target namespace
* @no_tcp: Disable TCP operation
* @tcp: Context for TCP protocol handler